<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Il y a une vie en dehors du navigateur !</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licence accordée à : %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 est un Logiciel Libre, mais son développement prend un temps précieux.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Merci &lt;a href=&apos;%1&apos;&gt;d&apos;envoyer vos dons&lt;/a&gt; pour aider à poursuivre le développement de %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduisez %1 dans votre langue native en utilisant %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Alimenté par %1</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Logiciel open-source</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icône dessinée par %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publié sous la licence &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Entrez les details de votre licence</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email :</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Code :</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Veuillez obtenir une licence pour %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>La version complète vous permet de voir des vidéos sans interruption.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>En achetant la version complète,vous supporterez aussi le grand travail que j&apos;ai investi dans la création de %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilisez la version de démonstration</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Entrer une licence</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Acheter une licence</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Téléchargements</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Par %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Vous avez %n nouvelle vidéo</numerusform><numerusform>Vous avez %n nouvelles vidéos</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Toutes les vidéos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vidéos non vues</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Dernièrement mis à jours</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Dernièrement ajoutées</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Dernièrement vues</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Les plus vues</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Trier par</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Tout marquer comme vu</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Afficher les mises à jours</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Vous n&apos;avez pas d&apos;abonnements. Utilisez le symbole en forme d&apos;étoile pour vous abonner à des chaines,</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Toutes les vidéos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vidéos non vues</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marquer comme vu</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Se désabonner</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Il n&apos;y a pas d&apos;abonnements mis à jour en ce moment.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Juste maintenant</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>Il y a une heure</numerusform><numerusform>Il y a %n heures</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>Il y a %n jour</numerusform><numerusform>Il y a %n jours</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>Il y a %n mois</numerusform><numerusform>Il y a %n mois</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 vues</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>Il y a %n semaine</numerusform><numerusform>Il y a %n semaines</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>Il y a %n an(s)</numerusform><numerusform>Il y a %n an(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>octets</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>Kio</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Mio</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>octets/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>Kio/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>Mio/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>secondes</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutes</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restant</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 téléchargé sur %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Téléchargement terminé</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n téléchargement</numerusform><numerusform>%n téléchargements</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Changer d&apos;emplacement...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Choisissez l&apos;emplacement de téléchargement</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Emplacement de téléchargement changé.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Les téléchargements en cours iront encore à l&apos;emplacement précédent.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Téléchargement de : %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Le fichier exécutable a été modifié avec, peut-être par un virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 ne sera pas exécuté. Essayez d&apos;installer à nouveau.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Lancer</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Lance/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Arrêtez la lecture après le morceau en cours</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Morceau suivant</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Monceau précédent</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Augmenter le volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuer le volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Avancer</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Retour</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Trouver des vidéos et des chaînes par mot-clé</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Parcourir</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Parcourir les vidéos par catégories</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnements</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Abonnements aux chaines</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Installez-vous confortablement</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Fenêtre</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Réduire</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Arrêter</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Arrêter et aller à la page de recherche</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;récédent</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Aller à la piste précédente</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Passer</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Passer à la vidéo suivante</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Jouer</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Relancer la lecture</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Mettre en plein écran</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Mode compact</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Cacher la liste de lecture et la barre d&apos;outils</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Ouvrir la page &amp;Youtube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Aller à la page de la vidéo Youtube et mettre en pause</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copier le &amp;lien Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copier l&apos;adresse de la vidéo YouTube courante dans le presse-papier</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copier l&apos;&amp;URL du flux vidéo </translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copier l&apos;adresse du flux vidéo courant dans le presse-papier</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Trouver les &amp;parties de la vidéo</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Trouver les autres parties de la vidéo en espérant qu&apos;elles soient dans le bon ordre</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Supprimer la vidéo sélectionnée de la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Déplacer vers les &amp;haut</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le haut dans la liste de lecture</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Déplacer vers les &amp;bas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Déplacer la vidéo sélectionnée vers le bas dans la liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Effacer les recherches récentes </translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Effacer l&apos;historique de recherche. Opération irréversible.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Au revoir</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Site &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sur le Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Faire un &amp;Don</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Merci d&apos;aider à poursuivre le développement de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;À propos</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>À propos de %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Couper le son</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Démarrer manuellement la lecture de vidéos</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Téléchargements</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Voir les détails à propos des téléchargements de la vidéo</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Téléchargement</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Télécharger la vidéo en cours</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Prendre un in&amp;stantané</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;S&apos;abonner à la chaine</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Partager cette vidéo avec %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Laisser au dessus</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Arrêter après cette vidéo</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Signaler un problème...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Affiner la recherche...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Plus…</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vidéos &amp;Relatives</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Regarder des vidéos relatives à la vidéo courante</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Ouvrir dans le &amp;navigateur ...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Mode restreint</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Masquer les vidéos qui peuvent contenir un contenu inapproprié</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Bascule la barre de &amp;Menu</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Aimer %1? Notez-le !</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Acheter %1 …</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Application</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Lecture</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Liste de lecture</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vidéo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Partager</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Appuyer sur %1 pour augmenter le volume, sur %2 pour le baisser</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Choisissez l&apos;emplacement de votre contenu</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Ouverture de %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Voulez-vous vraiment quitter %1 avec un téléchargement en cours ?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si vous fermez %1 maintenant, ce téléchargement sera annulé.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Fermer et annuler le téléchargement</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Attendez la fin du téléchargement</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erreur : %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Mettre en pause</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Chargement...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Quitter le &amp;mode plein écran</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Temps restant : %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume à %1</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume actif</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume inactif</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Résolution vidéo maximale fixée à %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Votre confidentialité est maintenant respectée</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Téléchargements terminés</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Vous pouvez continuer d&apos;accéder à la barre de menu en appuyant sur la touche ALT</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Vous pouvez maintenant copier l&apos;adresse Youtube dans une autre application</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Vous pouvez maintenant coller l&apos;adresse du flux vidéo dans une autre application</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Le lien ne sera valide que pour un temps limité.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>%1 Téléchargement</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>partie</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>épisode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Envoyé par %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Se désabonner de %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>S&apos;abonner à %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Basculé vers %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Se désabonner de %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>S&apos;abonner à %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>Rembobiner %1 secondes</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation>Avance rapide d e%1 secondes</translation>
    </message>
    <message>
        <source>channel</source>
        <translation>chaîne</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Une nouvelle version de %1 est disponible !</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 est maintenant disponible. Vous avez %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Voulez-vous la télécharger maintenant ?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Sauter cette version</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Me le rappeler plus tard</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installer la mise à jour</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Choisir une vidéo</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Préparation</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Échec</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Arrêter le téléchargement</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Montrer dans %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Ouvrir le dossier parent</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Redémarrer le téléchargement</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Afficher %1 de plus</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Pas de vidéos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Il n&apos;y a plus de vidéos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Trier par</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Pertinence</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Nombre de vues</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>N&apos;importe quand</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 jours</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 jours</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Tous</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Court</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Long</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Inférieur à 4 minutes</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 et 20 minutes</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Plus long que 20 minutes</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Qualité</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Terminer</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Cette année</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Chercher</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenue sur  &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>pour commencer à regarder des vidéos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>un mot-clé</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Entrer</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Derniers mots-clés</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Chaînes récentes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtenir la version complète</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation>Besoin d&apos;une  commande à distance pour %1 ? Essayez %2 !</translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation>Je continue d’améliorer %1 pour en faire le mieux que je peux. Soutenez ce travail!</translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation>Une mise à jour est prête à être installée. Quittez et installez la mise à jour.</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Retour</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Continuer</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Continuer à %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Revenir à %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Affiner la recherche</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Vouliez-vous dire : %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Changer d&apos;emplacement...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Instantané sauvé dans %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Emplacement de instantanés changé.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Les plus populaires</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>Tendance</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>News</source>
        <translation>Journaux</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Films</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Jeux</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Téléchargement de la mise à jour...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Téléchargement de %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>Vérifier les mises à jour...</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>La version %1 est disponible...</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation>Téléchargement de la version %1...</translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation>Redémarrez pour mettre à jour</translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>Le téléchargement de la version %1 a échoué</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>Vérifier les mises à jour</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Télécharger la mise à jour</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Téléchargement de la mise à jour...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation>Réessayer de télécharger la mise à jour</translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>Vous avez la dernière version</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>La version %1 est disponible.</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation>Une mise à jour a été téléchargée et est prête à être installée.</translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Impossible d&apos;obtenir le flux vidéo de %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algérie</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentine</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australie</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgique</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brésil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chili</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombie</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>République Tchèque</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Égypte</translation>
    </message>
    <message>
        <source>France</source>
        <translation>France</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Allemagne</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grèce</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hongrie</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Inde</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonésie</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irelande</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israël</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italie</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japon</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordanie</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaisie</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexique</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroc</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Pays-Bas</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nouvelle Zélande</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Pérou</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Philippines</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Pologne</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Russie</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabie Saoudite</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapour</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Afrique du Sud</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Corée du Sud</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Espagne</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suède</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taïwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisie</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquie</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Ouganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Émirats Arabes Unis</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Royaume Uni</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yémen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Monde entier</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Impossible d&apos;obtenir le flux vidéo de %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation>Il n&apos;y a actuellement aucune mise à jour disponible.</translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>Vous avez déjà la dernière version</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>Téléchargement de %1 %2...</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Une nouvelle version de %1 est disponible !</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 est maintenant disponible. Vous avez %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Voulez-vous la télécharger maintenant ?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Me le rappeler plus tard</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Télécharger la mise à jour</translation>
    </message>
</context>
</TS>